library(testthat)

# Set up path to example Excel file for testing
example_file <- system.file("extdata", "compound_template_example.xlsx", package = "autoDIKI")

# Test create_testX function
test_that("create_testX function works correctly", {
			# Check if the function returns a matrix
			test_matrix <- create_testX(example_file)
			expect_true(is.matrix(test_matrix), "The output should be a matrix")
			
			# Check if the matrix has the expected number of columns (match with `finalPredictors2use` columns)
			finalPredictors2use <- readRDS(system.file("extdata", "finalPredictors2use.rds", package = "autoDIKI"))
			expect_equal(as.numeric(ncol(test_matrix)), as.numeric(ncol(finalPredictors2use)),
					info = "The output matrix should have the same number of columns as `finalPredictors2use`")
			
			# Check if the matrix has row names corresponding to compound names
			expect_true(!is.null(rownames(test_matrix)), "The output matrix should have row names")
		})

# Test predict_nephrotoxicity function
test_that("predict_nephrotoxicity function works correctly", {
			# Generate test matrix using the create_testX function
			test_matrix <- create_testX(example_file)
			
			# Run prediction function
			results <- predict_nephrotoxicity(test_matrix)
			
			# Check if the results contain the expected elements
			expect_named(results, c("finalTable", "finalPlot"), 
					info = "The results should contain 'finalTable' and 'finalPlot'")
			
			# Test if finalTable is a data frame
			expect_true(is.data.frame(results$finalTable), "finalTable should be a data frame")
			
			# Check if finalTable contains the expected columns
			expect_true(all(c("Compound", "Probability of nephrotoxicity", "Predicted Class") %in% colnames(results$finalTable)),
					"finalTable should contain columns: Compound, Probability of nephrotoxicity, Predicted Class")
			
			# Test if finalPlot is a ggplot object
			expect_true(inherits(results$finalPlot, "ggplot"), "finalPlot should be a ggplot object")
		})
